@@ -1,10 +1,12 @@
 # Builtins
+import json
 import os
 import time
 import urllib.parse
 from io import BytesIO
 import re
 import base64
+from typing import Tuple
 
 # Client (Thank you!.. https://github.com/FlorianREGAZ)
 import tls_client
@@ -19,16 +21,11 @@ from reportlab.graphics import renderPM
 # Local
 from . import exceptions as Exceptions
 
-# Dot Env
-import dotenv
-from dotenv import load_dotenv
-
 # Fancy stuff
 import colorama
 from colorama import Fore
 
 colorama.init(autoreset=True)
-load_dotenv()
 
 
 def token_expired() -> bool:
@@ -38,39 +35,37 @@ def token_expired() -> bool:
             bool: True if expired, False if not
     """
     try:
-        # Get access token & expiry on env
-        access_token = os.getenv("CHATGPT_ACCESS_TOKEN")
-        expiry = os.getenv("CHATGPT_ACCESS_TOKEN_EXPIRY")
+        # Get path using os, it's in ./classes/auth.json
+        path = os.path.dirname(os.path.abspath(__file__))
+        path = os.path.join(path, "auth.json")
 
-        if not access_token or not expiry:
-            return True
-
-        print(f"{Fore.GREEN}>> Access token found in env variables.")
-        current_time = int(time.time())
-        # Check if it's expired
-        if current_time > int(expiry):
-            return True
-
-        return False
+        with open(path, 'r') as f:
+            creds = json.load(f)
+            expires_at = float(creds['expires_at'])
+            if time.time() > expires_at + 3600:
+                return True
+            else:
+                return False
     except FileNotFoundError:
         return True
 
 
-def get_access_token() -> str:
+def get_access_token() -> Tuple[str or None, str or None]:
     """
         Get the access token
         returns:
             str: The access token
     """
     try:
-        # Get access token on env
-        access_token = os.getenv("CHATGPT_ACCESS_TOKEN")
-        if not access_token:
-            return ""
+        # Get path using os, it's in ./Classes/auth.json
+        path = os.path.dirname(os.path.abspath(__file__))
+        path = os.path.join(path, "auth.json")
 
-        return access_token
+        with open(path, 'r') as f:
+            creds = json.load(f)
+            return creds['access_token'], creds['expires_at']
     except FileNotFoundError:
-        return ""
+        return None, None
 
 
 class Auth:
@@ -374,15 +369,11 @@ class Auth:
             print(f"{Fore.GREEN}[OpenAI][9] {Fore.WHITE}Saving access token...")
             expiry = expiry or int(time.time()) + 3600
 
-            os.environ["CHATGPT_ACCESS_TOKEN"] = access_token
-            os.environ["CHATGPT_ACCESS_TOKEN_EXPIRY"] = str(expiry)
-
-            dotenv.set_key(dotenv_path=dotenv.find_dotenv(),
-                           key_to_set="CHATGPT_ACCESS_TOKEN",
-                           value_to_set=access_token)
-            dotenv.set_key(dotenv_path=dotenv.find_dotenv(),
-                           key_to_set="CHATGPT_ACCESS_TOKEN_EXPIRY",
-                           value_to_set=expiry)
+            # Get path using os, it's in ./classes/auth.json
+            path = os.path.dirname(os.path.abspath(__file__))
+            path = os.path.join(path, "auth.json")
+            with open(path, "w") as f:
+                f.write(json.dumps({"access_token": access_token, "expires_at": expiry}))
 
             print(f"{Fore.GREEN}[OpenAI][8] {Fore.WHITE}Saved access token")
         except Exception as e:
